==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/haplo.stats.wrapers.R <==
# wrapers for some functions in haplo.stats package

getGenoY<-function(geneSetObj)
{

  tmp<-geneSet2Ped2(geneSetObj) 
  ped<-tmp$ped
  columns<-tmp$columns

  len<-length(columns)
  geno<-ped[,-c(1:len)]
  y<-as.vector(ped[,6])
  y[y>0]<-y[y>0]-1

  tmp2<-geneSetObj@markerInfo
  locus.label<-tmp2[,1]

  return(list(y=y, geno=geno, locus.label=locus.label))
}


haplo.em.w <- function (geneSetObj, locus.label=NA, miss.val=c(0, NA), 
                weight=NULL, control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.em(geno, locus.label, miss.val, weight, control)
  invisible(res)
}

haplo.scan.w<-function(geneSetObj, width=4, miss.val=c(0, NA),
               em.control=haplo.em.control(),
               sim.control=score.sim.control())
{

  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.scan(y, geno, width, miss.val, em.control, sim.control)
  invisible(res)
}

haplo.score.w <- function (geneSetObj, trait.type="gaussian", offset = NA,
                 x.adj = NA, skip.haplo=5/(2*nrow(geno)), locus.label=NA,
                 miss.val=c(0,NA), simulate=FALSE, 
                 sim.control=score.sim.control(),
                 em.control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.score(y, geno, trait.type, offset, x.adj, skip.haplo, 
                   locus.label, miss.val, simulate, sim.control, em.control)
  invisible(res)
}

haplo.score.slide.w<-function(geneSetObj, trait.type="gaussian", n.slide=2,
                       offset = NA, x.adj = NA, skip.haplo=5/(2*nrow(geno)),
                       locus.label=NA, miss.val=c(0,NA),
                       simulate=FALSE, sim.control=score.sim.control(),
                       em.control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.score.slide(y, geno, trait.type, n.slide,
                       offset, x.adj, skip.haplo,
                       locus.label, miss.val,
                       simulate, sim.control,
                       em.control)
  invisible(res)
}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/haplo.stats.wrapers.R <==
# wrapers for some functions in haplo.stats package

getGenoY<-function(geneSetObj)
{

  #tmp<-geneSet2Ped2(geneSetObj) 
  tmp<-geneSet2Ped(geneSetObj) 
  ped<-tmp$ped
  columns<-tmp$columns

  len<-length(columns)
  geno<-ped[,-c(1:len), drop=FALSE]
  y<-as.vector(ped[,6])
  y[y>0]<-y[y>0]-1

  tmp2<-geneSetObj@markerInfo
  locus.label<-tmp2[,1]

  return(list(y=y, geno=geno, locus.label=locus.label))
}


haplo.em.w <- function (geneSetObj, locus.label=NA, miss.val=c(0, NA), 
                weight=NULL, control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.em(geno, locus.label, miss.val, weight, control)
  invisible(res)
}

haplo.scan.w<-function(geneSetObj, width=4, miss.val=c(0, NA),
               em.control=haplo.em.control(),
               sim.control=score.sim.control())
{

  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.scan(y, geno, width, miss.val, em.control, sim.control)
  invisible(res)
}

haplo.score.w <- function (geneSetObj, trait.type="gaussian", offset = NA,
                 x.adj = NA, skip.haplo=5/(2*nrow(geno)), locus.label=NA,
                 miss.val=c(0,NA), simulate=FALSE, 
                 sim.control=score.sim.control(),
                 em.control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.score(y, geno, trait.type, offset, x.adj, skip.haplo, 
                   locus.label, miss.val, simulate, sim.control, em.control)
  invisible(res)
}

haplo.score.slide.w<-function(geneSetObj, trait.type="gaussian", n.slide=2,
                       offset = NA, x.adj = NA, skip.haplo=5/(2*nrow(geno)),
                       locus.label=NA, miss.val=c(0,NA),
                       simulate=FALSE, sim.control=score.sim.control(),
                       em.control=haplo.em.control())
{
  tmp<-getGenoY(geneSetObj)
  y<-tmp$y
  geno<-tmp$geno
  columns<-tmp$columns
  locus.label<-tmp$locus.label

  res<-haplo.score.slide(y, geno, trait.type, n.slide,
                       offset, x.adj, skip.haplo,
                       locus.label, miss.val,
                       simulate, sim.control,
                       em.control)
  invisible(res)
}
